<?php

namespace Drupal\ignition\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Ignition settings for this site.
 */
class IgnitionSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ignition_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['ignition.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $ignition_config = $this->config('ignition.settings');

    $form['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $ignition_config->get('enabled') === TRUE ? TRUE : FALSE,
      '#description' => $this->t('Warning: Only enable for development environments where you need debugging information.'),
    ];

    $form['dark_mode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Dark mode'),
      '#default_value' => $ignition_config->get('dark_mode') === TRUE ? TRUE : FALSE,
      '#description' => $this->t('Enable dark mode for the Ignition error page.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('ignition.settings')
      ->set('enabled', $form_state->getValue('enabled'))
      ->set('dark_mode', $form_state->getValue('dark_mode'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
