<?php

namespace Drupal\ignition;

use Drupal\Core\Config\ConfigFactoryInterface;
use Spatie\Ignition\Contracts\HasSolutionsForThrowable;
use Spatie\Ignition\Ignition;

/**
 * A factory for the Ignition service.
 */
class IgnitionFactory {

  /**
   * Constructs an IgnitionFactory object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\ignition\SolutionProviderCollector $solutionProviderCollector
   *   The solution provider collector.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
    protected SolutionProviderCollector $solutionProviderCollector,
  ) {
  }

  /**
   * Create a configured instance of the Ignition service.
   */
  public function make(): Ignition {
    $config = $this->configFactory->get('ignition.settings');
    $ignition = Ignition::make()
      ->applicationPath(DRUPAL_ROOT);

    $providers = $this->solutionProviderCollector->getSolutionProviders();
    $ignition->addSolutionProviders($providers);

    if ($config->get('dark_mode') == TRUE) {
      $ignition->setTheme('dark');
    }

    return $ignition;
  }

}
